[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [kdelibs/frameworks] /: Trim down KLineEdit uses when possible
From:       Kevin Ottens <ervin+bluesystems () kde ! org>
Date:       2013-08-19 14:08:43
Message-ID: E1VBQ8R-0006Mq-83 () scm ! kde ! org
[Download RAW message or body]

Git commit 792949902ecb7b39b1fe9cf4b25f0f72cfbfc13b by Kevin Ottens.
Committed on 19/08/2013 at 10:45.
Pushed by ervin into branch 'frameworks'.

Trim down KLineEdit uses when possible

M  +1    -1    kfile/kfileplaceeditdialog.cpp
M  +3    -3    kfile/kfileplaceeditdialog.h
M  +2    -2    kfile/knameandurlinputdialog.cpp
M  +5    -11   kfile/knewfilemenu.cpp
M  +2    -2    kio/tests/previewtest.cpp
M  +2    -2    kio/tests/previewtest.h
M  +0    -1    kioslave/http/kcookiejar/CMakeLists.txt
M  +7    -7    kioslave/http/kcookiejar/kcookiewin.cpp
M  +7    -7    kioslave/http/kcookiejar/kcookiewin.h
M  +7    -12   knewstuff/knewstuff3/uploaddialog.ui
M  +1    -1    kross/ui/CMakeLists.txt
M  +9    -9    kross/ui/view.cpp
M  +0    -1    kutils/CMakeLists.txt
M  +3    -3    kutils/kpluginselector.cpp
M  +2    -2    kutils/kpluginselector_p.h
M  +2    -2    staging/kemoticons/tests/main.cpp
M  +2    -2    staging/kio/src/widgets/pastedialog.cpp
M  +2    -2    staging/kio/src/widgets/pastedialog.h
M  +7    -7    staging/ktextwidgets/src/dialogs/klinkdialog.cpp

http://commits.kde.org/kdelibs/792949902ecb7b39b1fe9cf4b25f0f72cfbfc13b

diff --git a/kfile/kfileplaceeditdialog.cpp b/kfile/kfileplaceeditdialog.cpp
index 73968f0..328478e 100644
--- a/kfile/kfileplaceeditdialog.cpp
+++ b/kfile/kfileplaceeditdialog.cpp
@@ -98,7 +98,7 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const \
                QUrl& url,
                                  "that will help you remember what this entry refers \
                to. "
                                  "If you do not enter a label, it will be derived \
from "  "the location's URL.</qt>");
-    m_labelEdit = new KLineEdit(this);
+    m_labelEdit = new QLineEdit(this);
     layout->addRow(i18n("L&abel:"), m_labelEdit);
     m_labelEdit->setText(label);
     m_labelEdit->setPlaceholderText(i18n("Enter descriptive label here"));
diff --git a/kfile/knameandurlinputdialog.cpp b/kfile/knameandurlinputdialog.cpp
index 727b433..bbfa046 100644
--- a/kfile/knameandurlinputdialog.cpp
+++ b/kfile/knameandurlinputdialog.cpp
@@ -39,7 +39,7 @@ public:
     /**
      * The line edit widget for the fileName
      */
-    KLineEdit *m_leName;
+    QLineEdit *m_leName;
     /**
      * The URL requester for the URL :)
      */
@@ -64,7 +64,7 @@ KNameAndUrlInputDialog::KNameAndUrlInputDialog(const QString& \
nameLabel, const Q  formLayout->setMargin(0);
 
     // First line: filename
-    d->m_leName = new KLineEdit(this);
+    d->m_leName = new QLineEdit(this);
     d->m_leName->setMinimumWidth(d->m_leName->sizeHint().width() * 3);
     d->m_leName->setSelection(0, d->m_leName->text().length()); // autoselect
     connect(d->m_leName, SIGNAL(textChanged(QString)),
diff --git a/kfile/knewfilemenu.cpp b/kfile/knewfilemenu.cpp
index d870e4d..9757f08 100644
--- a/kfile/knewfilemenu.cpp
+++ b/kfile/knewfilemenu.cpp
@@ -27,6 +27,7 @@
 #include <QVBoxLayout>
 #include <QList>
 #include <QLabel>
+#include <QLineEdit>
 #include <QMenu>
 #include <QStandardPaths>
 
@@ -38,7 +39,6 @@
 #include <kdirwatch.h>
 #include <kjobwidgets.h>
 #include <klocalizedstring.h>
-#include <klineedit.h>
 #include <kmessagebox.h>
 #include <kprotocolinfo.h>
 #include <kprotocolmanager.h>
@@ -475,11 +475,8 @@ void KNewFileMenuPrivate::executeRealFileOrDir(const \
KNewFileMenuSingleton::Entr  QVBoxLayout *layout = new QVBoxLayout;
     QLabel *label = new QLabel(entry.comment, fileDialog);
 
-    // We don't set the text of lineEdit in its constructor because the clear button \
                would not be shown then.
-    // It seems that setClearButtonShown(true) must be called *before* the text is \
                set to make it work.
-    // TODO: should probably be investigated and fixed in KLineEdit.
-    KLineEdit *lineEdit = new KLineEdit(fileDialog);
-    lineEdit->setClearButtonShown(true);
+    QLineEdit *lineEdit = new QLineEdit(fileDialog);
+    lineEdit->setClearButtonEnabled(true);
     lineEdit->setText(text);
 
     _k_slotTextChanged(text);
@@ -1045,11 +1042,8 @@ void KNewFileMenu::createDirectory()
     QVBoxLayout *layout = new QVBoxLayout;
     QLabel *label = new QLabel(i18n("Create new folder in:\n%1", \
baseUrl.toDisplayString(QUrl::PreferLocalFile)), fileDialog);  
-    // We don't set the text of lineEdit in its constructor because the clear button \
                would not be shown then.
-    // It seems that setClearButtonShown(true) must be called *before* the text is \
                set to make it work.
-    // TODO: should probably be investigated and fixed in KLineEdit.
-    KLineEdit *lineEdit = new KLineEdit(fileDialog);
-    lineEdit->setClearButtonShown(true);
+    QLineEdit *lineEdit = new QLineEdit(fileDialog);
+    lineEdit->setClearButtonEnabled(true);
     lineEdit->setText(name);
 
     d->_k_slotTextChanged(name); // have to save string in d->m_text in case user \
                does not touch dialog
diff --git a/kio/tests/previewtest.cpp b/kio/tests/previewtest.cpp
index 369dfbe..bfc66bf 100644
--- a/kio/tests/previewtest.cpp
+++ b/kio/tests/previewtest.cpp
@@ -4,10 +4,10 @@
 #include <QLabel>
 #include <QApplication>
 #include <QLayout>
+#include <QLineEdit>
 #include <QPushButton>
 
 #include <QDebug>
-#include <klineedit.h>
 #include <kiconloader.h>
 #include <kio/previewjob.h>
 
@@ -17,7 +17,7 @@ PreviewTest::PreviewTest()
     :QWidget()
 {
     QGridLayout *layout = new QGridLayout(this);
-    m_url = new KLineEdit(this);
+    m_url = new QLineEdit(this);
 
     QString path;
     KIconLoader().loadMimeTypeIcon("video-x-generic", KIconLoader::Desktop, 256,
diff --git a/kio/tests/previewtest.h b/kio/tests/previewtest.h
index 6028939..7128a85 100644
--- a/kio/tests/previewtest.h
+++ b/kio/tests/previewtest.h
@@ -4,7 +4,7 @@
 #include <qwidget.h>
 #include <kio/job.h>
 
-class KLineEdit;
+class QLineEdit;
 class QLabel;
 class KFileItem;
 
@@ -21,7 +21,7 @@ private Q_SLOTS:
     void slotFailed();
 
 private:
-    KLineEdit *m_url;
+    QLineEdit *m_url;
     QLabel *m_preview;
 };
 
diff --git a/kioslave/http/kcookiejar/CMakeLists.txt \
b/kioslave/http/kcookiejar/CMakeLists.txt index 0a7217a..135400b 100644
--- a/kioslave/http/kcookiejar/CMakeLists.txt
+++ b/kioslave/http/kcookiejar/CMakeLists.txt
@@ -47,7 +47,6 @@ target_link_libraries(kded_kcookiejar
    KCoreAddons
    KDBusAddons
    KI18n
-   KCompletion
    KWidgetsAddons
    KInterProcessWindowing
 )
diff --git a/kioslave/http/kcookiejar/kcookiewin.cpp \
b/kioslave/http/kcookiejar/kcookiewin.cpp index c4ebc69..4c0ecd1 100644
--- a/kioslave/http/kcookiejar/kcookiewin.cpp
+++ b/kioslave/http/kcookiejar/kcookiewin.cpp
@@ -41,6 +41,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE \
SOFTWARE.  #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLayout>
+#include <QLineEdit>
 #include <QGroupBox>
 #include <QPushButton>
 #include <QRadioButton>
@@ -50,7 +51,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE \
SOFTWARE.  
 #include <kwindowsystem.h>
 #include <klocalizedstring.h>
-#include <klineedit.h>
 #include <kusertimestamp.h>
 
 enum {
@@ -259,7 +259,7 @@ KCookieDetail::KCookieDetail( KHttpCookieList cookieList, int \
cookieCount,  
     QLabel* label = new QLabel( i18n("Name:"), this );
     grid->addWidget( label, 1, 0 );
-    m_name = new KLineEdit( this );
+    m_name = new QLineEdit( this );
     m_name->setReadOnly( true );
     m_name->setMaximumWidth( fontMetrics().maxWidth() * 25 );
     grid->addWidget( m_name, 1 ,1 );
@@ -267,35 +267,35 @@ KCookieDetail::KCookieDetail( KHttpCookieList cookieList, int \
cookieCount,  //Add the value
     label = new QLabel( i18n("Value:"), this );
     grid->addWidget( label, 2, 0 );
-    m_value = new KLineEdit( this );
+    m_value = new QLineEdit( this );
     m_value->setReadOnly( true );
     m_value->setMaximumWidth( fontMetrics().maxWidth() * 25 );
     grid->addWidget( m_value, 2, 1);
 
     label = new QLabel( i18n("Expires:"), this );
     grid->addWidget( label, 3, 0 );
-    m_expires = new KLineEdit( this );
+    m_expires = new QLineEdit( this );
     m_expires->setReadOnly( true );
     m_expires->setMaximumWidth(fontMetrics().maxWidth() * 25 );
     grid->addWidget( m_expires, 3, 1);
 
     label = new QLabel( i18n("Path:"), this );
     grid->addWidget( label, 4, 0 );
-    m_path = new KLineEdit( this );
+    m_path = new QLineEdit( this );
     m_path->setReadOnly( true );
     m_path->setMaximumWidth( fontMetrics().maxWidth() * 25 );
     grid->addWidget( m_path, 4, 1);
 
     label = new QLabel( i18n("Domain:"), this );
     grid->addWidget( label, 5, 0 );
-    m_domain = new KLineEdit( this );
+    m_domain = new QLineEdit( this );
     m_domain->setReadOnly( true );
     m_domain->setMaximumWidth( fontMetrics().maxWidth() * 25 );
     grid->addWidget( m_domain, 5, 1);
 
     label = new QLabel( i18n("Exposure:"), this );
     grid->addWidget( label, 6, 0 );
-    m_secure = new KLineEdit( this );
+    m_secure = new QLineEdit( this );
     m_secure->setReadOnly( true );
     m_secure->setMaximumWidth( fontMetrics().maxWidth() * 25 );
     grid->addWidget( m_secure, 6, 1 );
diff --git a/kioslave/http/kcookiejar/kcookiewin.h \
b/kioslave/http/kcookiejar/kcookiewin.h index 5dc3f6a..938cb7a 100644
--- a/kioslave/http/kcookiejar/kcookiewin.h
+++ b/kioslave/http/kcookiejar/kcookiewin.h
@@ -31,7 +31,7 @@
 #include <QDialog>
 #include "kcookiejar.h"
 
-class KLineEdit;
+class QLineEdit;
 class QPushButton;
 
 class KCookieDetail : public QGroupBox
@@ -49,12 +49,12 @@ private Q_SLOTS:
 private:
     void displayCookieDetails();
 
-    KLineEdit*   m_name;
-    KLineEdit*   m_value;
-    KLineEdit*   m_expires;
-    KLineEdit*   m_domain;
-    KLineEdit*   m_path;
-    KLineEdit*   m_secure;
+    QLineEdit*   m_name;
+    QLineEdit*   m_value;
+    QLineEdit*   m_expires;
+    QLineEdit*   m_domain;
+    QLineEdit*   m_path;
+    QLineEdit*   m_secure;
 
     KHttpCookieList m_cookieList;
     int m_cookieNumber;
diff --git a/knewstuff/knewstuff3/uploaddialog.ui \
b/knewstuff/knewstuff3/uploaddialog.ui index 9c3fca9..33983df 100644
--- a/knewstuff/knewstuff3/uploaddialog.ui
+++ b/knewstuff/knewstuff3/uploaddialog.ui
@@ -71,9 +71,9 @@
         </spacer>
        </item>
        <item row="2" column="1">
-        <widget class="KLineEdit" name="password">
-         <property name="passwordMode">
-          <bool>true</bool>
+        <widget class="QLineEdit" name="password">
+         <property name="echoMode">
+          <bool>QLineEdit::Password</bool>
          </property>
         </widget>
        </item>
@@ -113,7 +113,7 @@
         <widget class="QComboBox" name="providerComboBox"/>
        </item>
        <item row="1" column="1">
-        <widget class="KLineEdit" name="username"/>
+        <widget class="QLineEdit" name="username"/>
        </item>
        <item row="0" column="0">
         <widget class="QLabel" name="label_9">
@@ -268,7 +268,7 @@
         </widget>
        </item>
        <item row="3" column="2" colspan="2">
-        <widget class="KLineEdit" name="mVersionEdit"/>
+        <widget class="QLineEdit" name="mVersionEdit"/>
        </item>
        <item row="1" column="1">
         <widget class="QLabel" name="label_4">
@@ -312,7 +312,7 @@
         </widget>
        </item>
        <item row="1" column="2" colspan="2">
-        <widget class="KLineEdit" name="mNameEdit">
+        <widget class="QLineEdit" name="mNameEdit">
          <property name="toolTip">
           <string>Name of the file as it will appear on the website</string>
          </property>
@@ -484,7 +484,7 @@
            </widget>
           </item>
           <item row="1" column="1" colspan="2">
-           <widget class="KLineEdit" name="priceReasonLineEdit"/>
+           <widget class="QLineEdit" name="priceReasonLineEdit"/>
           </item>
          </layout>
         </widget>
@@ -797,11 +797,6 @@
    <header>ktitlewidget.h</header>
   </customwidget>
   <customwidget>
-   <class>KLineEdit</class>
-   <extends>QLineEdit</extends>
-   <header>klineedit.h</header>
-  </customwidget>
-  <customwidget>
    <class>KComboBox</class>
    <extends>QComboBox</extends>
    <header>kcombobox.h</header>
diff --git a/kross/ui/CMakeLists.txt b/kross/ui/CMakeLists.txt
index 9aa634d..580d3c9 100644
--- a/kross/ui/CMakeLists.txt
+++ b/kross/ui/CMakeLists.txt
@@ -7,7 +7,7 @@ set(krossui_LIB_SRCS
    )
 
 kde4_add_library(krossui ${LIBRARY_TYPE} ${krossui_LIB_SRCS})
-target_link_libraries(krossui krosscore ${KDE4_KPARTS_LIBS} ${KDE4_KIO_LIBS} \
${KCoreAddons_LIBRARIES} KI18n KCompletion XmlGui KIconThemes) \
+target_link_libraries(krossui krosscore ${KDE4_KPARTS_LIBS} ${KDE4_KIO_LIBS} \
${KCoreAddons_LIBRARIES} KI18n XmlGui KIconThemes)  set_target_properties(krossui \
                PROPERTIES VERSION ${GENERIC_LIB_VERSION}
                                          SOVERSION ${GENERIC_LIB_SOVERSION}
                      )
diff --git a/kross/ui/view.cpp b/kross/ui/view.cpp
index 51f31c5..086938e 100644
--- a/kross/ui/view.cpp
+++ b/kross/ui/view.cpp
@@ -31,6 +31,7 @@
 #include <QAction>
 #include <QBoxLayout>
 #include <QHeaderView>
+#include <QLineEdit>
 #include <QPushButton>
 #include <QTreeView>
 #include <QLabel>
@@ -44,7 +45,6 @@
 #include <kcombobox.h>
 #include <kiconbutton.h>
 #include <klocalizedstring.h>
-#include <klineedit.h>
 #include <kurlrequester.h>
 
 //#include <ktar.h>
@@ -85,10 +85,10 @@ namespace Kross {
                 return type == ActionType ? action->isEnabled() : \
collection->isEnabled();  }
 
-            KLineEdit* nameedit;
-            KLineEdit* textedit;
-            KLineEdit* commentedit;
-            KLineEdit* iconedit;
+            QLineEdit* nameedit;
+            QLineEdit* textedit;
+            QLineEdit* commentedit;
+            QLineEdit* iconedit;
             KComboBox* interpreteredit;
             KUrlRequester* fileedit;
             //QCheckBox* enabledcheckbox;
@@ -147,7 +147,7 @@ void ActionCollectionEditor::initGui()
 
     QLabel* namelabel = new QLabel(i18n("Name:"), w);
     gridlayout->addWidget(namelabel, 0, 0);
-    d->nameedit = new KLineEdit(w);
+    d->nameedit = new QLineEdit(w);
     namelabel->setBuddy(d->nameedit);
     d->nameedit->setText( d->name() );
     d->nameedit->setEnabled(false);
@@ -155,14 +155,14 @@ void ActionCollectionEditor::initGui()
 
     QLabel* textlabel = new QLabel(i18n("Text:"), w);
     gridlayout->addWidget(textlabel, 1, 0);
-    d->textedit = new KLineEdit(w);
+    d->textedit = new QLineEdit(w);
     textlabel->setBuddy(d->textedit);
     d->textedit->setText( d->text() );
     gridlayout->addWidget(d->textedit, 1, 1);
 
     QLabel* commentlabel = new QLabel(i18n("Comment:"), w);
     gridlayout->addWidget(commentlabel, 2, 0);
-    d->commentedit = new KLineEdit(w);
+    d->commentedit = new QLineEdit(w);
     commentlabel->setBuddy(d->commentedit);
     d->commentedit->setText( d->description() );
     gridlayout->addWidget(d->commentedit, 2, 1);
@@ -173,7 +173,7 @@ void ActionCollectionEditor::initGui()
     QHBoxLayout* iconlayout = new QHBoxLayout();
     iconlayout->setMargin(0);
     iconbox->setLayout(iconlayout);
-    d->iconedit = new KLineEdit(iconbox);
+    d->iconedit = new QLineEdit(iconbox);
     iconlabel->setBuddy(d->iconedit);
     d->iconedit->setText( d->iconName() );
     iconlayout->addWidget(d->iconedit, 1);
diff --git a/kutils/CMakeLists.txt b/kutils/CMakeLists.txt
index 5a488dc..0f7f8f1 100644
--- a/kutils/CMakeLists.txt
+++ b/kutils/CMakeLists.txt
@@ -28,7 +28,6 @@ target_link_libraries(kcmutils
     ${KCoreAddons_LIBRARIES}
     ${KWidgetsAddons_LIBRARIES}
     KI18n
-    KCompletion
     KIconThemes     # KIconLoader
     ItemViews       # KWidgetItemDelegate
     XmlGui          # KAboutApplicationDialog
diff --git a/kutils/kpluginselector.cpp b/kutils/kpluginselector.cpp
index 6cec41c..5f68aec 100644
--- a/kutils/kpluginselector.cpp
+++ b/kutils/kpluginselector.cpp
@@ -26,6 +26,7 @@
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QLabel>
+#include <QLineEdit>
 #include <QPainter>
 #include <QBoxLayout>
 #include <QApplication>
@@ -36,7 +37,6 @@
 #include <QStyleOptionViewItemV4>
 
 #include <QDebug>
-#include <klineedit.h>
 #include <kurllabel.h>
 #include <kcmoduleinfo.h>
 #include <kcmoduleproxy.h>
@@ -256,8 +256,8 @@ KPluginSelector::KPluginSelector(QWidget *parent)
     layout->setMargin(0);
     setLayout(layout);
 
-    d->lineEdit = new KLineEdit(this);
-    d->lineEdit->setClearButtonShown(true);
+    d->lineEdit = new QLineEdit(this);
+    d->lineEdit->setClearButtonEnabled(true);
     d->lineEdit->setPlaceholderText(i18n("Search Plugins"));
     d->listView = new KCategorizedView(this);
     d->listView->setVerticalScrollMode(QListView::ScrollPerPixel);
diff --git a/kutils/kpluginselector_p.h b/kutils/kpluginselector_p.h
index 068f060..2dffae0 100644
--- a/kutils/kpluginselector_p.h
+++ b/kutils/kpluginselector_p.h
@@ -31,10 +31,10 @@
 
 class QLabel;
 class QCheckBox;
+class QLineEdit;
 class QPushButton;
 class QAbstractItemView;
 
-class KLineEdit;
 class KCategorizedView;
 class KCModuleProxy;
 class KCategoryDrawer;
@@ -74,7 +74,7 @@ public:
     class PluginDelegate;
     class DependenciesWidget;
     KPluginSelector *parent;
-    KLineEdit *lineEdit;
+    QLineEdit *lineEdit;
     KCategorizedView *listView;
     KCategoryDrawer *categoryDrawer;
     PluginModel *pluginModel;
diff --git a/staging/kemoticons/tests/main.cpp b/staging/kemoticons/tests/main.cpp
index 20378eb..f46265e 100644
--- a/staging/kemoticons/tests/main.cpp
+++ b/staging/kemoticons/tests/main.cpp
@@ -21,7 +21,7 @@
 #include <QApplication>
 #include <QDebug>
 #include <qstring.h>
-#include <klineedit.h>
+#include <qlineedit.h>
 #include <qlabel.h>
 #include <kcombobox.h>
 #include <QVBoxLayout>
@@ -38,7 +38,7 @@ class KEmoTest : public QWidget
         void changeTheme(const QString&theme);
     
     private:
-        KLineEdit kl;
+        QLineEdit kl;
         QLabel lb;
         KEmoticons e;
         KEmoticonsTheme t;
diff --git a/staging/kio/src/widgets/pastedialog.cpp \
b/staging/kio/src/widgets/pastedialog.cpp index d68e9b1..b7b195a 100644
--- a/staging/kio/src/widgets/pastedialog.cpp
+++ b/staging/kio/src/widgets/pastedialog.cpp
@@ -19,13 +19,13 @@
 #include "pastedialog.h"
 
 #include <kcombobox.h>
-#include <klineedit.h>
 #include <klocalizedstring.h>
 
 #include <QApplication>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLayout>
+#include <QLineEdit>
 #include <QClipboard>
 
 KIO::PasteDialog::PasteDialog( const QString &caption, const QString &label,
@@ -48,7 +48,7 @@ KIO::PasteDialog::PasteDialog( const QString &caption, const \
QString &label,  m_label = new QLabel( label, frame );
     layout->addWidget( m_label );
 
-    m_lineEdit = new KLineEdit( value, frame );
+    m_lineEdit = new QLineEdit( value, frame );
     layout->addWidget( m_lineEdit );
 
     m_lineEdit->setFocus();
diff --git a/staging/kio/src/widgets/pastedialog.h \
b/staging/kio/src/widgets/pastedialog.h index 3666a47..d8f5018 100644
--- a/staging/kio/src/widgets/pastedialog.h
+++ b/staging/kio/src/widgets/pastedialog.h
@@ -22,7 +22,7 @@
 #include <QDialog>
 
 class KComboBox;
-class KLineEdit;
+class QLineEdit;
 class QLabel;
 
 namespace KIO {
@@ -48,7 +48,7 @@ private Q_SLOTS:
 
 private:
     QLabel* m_label;
-    KLineEdit* m_lineEdit;
+    QLineEdit* m_lineEdit;
     KComboBox* m_comboBox;
     bool m_clipboardChanged;
 
diff --git a/staging/ktextwidgets/src/dialogs/klinkdialog.cpp \
b/staging/ktextwidgets/src/dialogs/klinkdialog.cpp index be436de..fc1dd08 100644
--- a/staging/ktextwidgets/src/dialogs/klinkdialog.cpp
+++ b/staging/ktextwidgets/src/dialogs/klinkdialog.cpp
@@ -22,10 +22,10 @@
 #include "klinkdialog_p.h"
 
 #include <klocalizedstring.h>
-#include <klineedit.h>
 
 #include <QDialogButtonBox>
 #include <QLabel>
+#include <QLineEdit>
 #include <QGridLayout>
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -39,9 +39,9 @@ class KLinkDialogPrivate
 {
 public:
     QLabel *textLabel;
-    KLineEdit *textLineEdit;
+    QLineEdit *textLineEdit;
     QLabel *linkUrlLabel;
-    KLineEdit *linkUrlLineEdit;
+    QLineEdit *linkUrlLineEdit;
     QDialogButtonBox *buttonBox;
 };
 //@endcond
@@ -58,11 +58,11 @@ KLinkDialog::KLinkDialog(QWidget *parent)
     QGridLayout *grid = new QGridLayout;
 
     d->textLabel = new QLabel(i18n("Link Text:"), this);
-    d->textLineEdit = new KLineEdit(this);
-    d->textLineEdit->setClearButtonShown(true);
+    d->textLineEdit = new QLineEdit(this);
+    d->textLineEdit->setClearButtonEnabled(true);
     d->linkUrlLabel = new QLabel(i18n("Link URL:"), this);
-    d->linkUrlLineEdit = new KLineEdit(this);
-    d->linkUrlLineEdit->setClearButtonShown(true);
+    d->linkUrlLineEdit = new QLineEdit(this);
+    d->linkUrlLineEdit->setClearButtonEnabled(true);
 
     grid->addWidget(d->textLabel, 0, 0);
     grid->addWidget(d->textLineEdit, 0, 1);


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
diff --git a/kfile/kfileplaceeditdialog.h b/kfile/kfileplaceeditdialog.h
index 7284ead..5847bb8 100644
--- a/kfile/kfileplaceeditdialog.h
+++ b/kfile/kfileplaceeditdialog.h
@@ -29,8 +29,8 @@
 
 class QCheckBox;
 class QDialogButtonBox;
+class QLineEdit;
 class KIconButton;
-class KLineEdit;
 class KUrlRequester;
 
 /**
@@ -129,9 +129,9 @@ private:
      */
     KUrlRequester * m_urlEdit;
     /**
      * The KLineEdit used for editing the label
      */
-    KLineEdit     * m_labelEdit;
+    QLineEdit     * m_labelEdit;
     /**
      * The KIconButton to configure the icon
      */
@@ -129,9 +129,9 @@ private:
     KUrlRequester * m_urlEdit;
     /**
-     * The KLineEdit used for editing the label
+     * The QLineEdit used for editing the label
      */